@@ -180,14 +180,21 @@ impl Store {
         let order_key_2 = order_key.clone();
         let order = web::block(move || tree.get(order_key_2)).await??;
 
+        let order_key_2 = order_key.clone();
+        let entries = self
+            .entries(order_key_2, config.move_entry_path.entry_range())
+            .await?;
+        let iter = entries.into_iter().map(|(k, _)| k);
         let mut order = if let Some(order) = order {
-            serde_json::from_slice::<Vec<Uuid>>(&order)?
+            let mut v = serde_json::from_slice::<Vec<Uuid>>(&order)?;
+
+            let iter = iter.filter(|uuid| !v.contains(uuid)).collect::<Vec<_>>();
+
+            v.extend(iter);
+
+            v
         } else {
-            let order_key_2 = order_key.clone();
-            let entries = self
-                .entries(order_key_2, config.move_entry_path.entry_range())
-                .await?;
-            entries.into_iter().map(|(k, _)| k).collect()
+            iter.collect()
         };
 
         let entry_uuid = config.move_entry_path.entry;
